##############################################
Teledyne T3AFG Arbitrary Waveform Generator
##############################################

.. autoclass:: pymeasure.instruments.teledyne.TeledyneT3AFG
    :members:
    :show-inheritance:
    :inherited-members: CommonBase

.. autoclass:: pymeasure.instruments.teledyne.teledyneT3AFG.SignalChannel
    :members:
    :show-inheritance:

